scipy.sparse.bsr_matrix
=======================

.. currentmodule:: scipy.sparse

.. autoclass:: bsr_matrix

   

   .. HACK
      .. autosummary::
         :toctree:
      
         bsr_matrix.__init__
         bsr_matrix.asformat
         bsr_matrix.asfptype
         bsr_matrix.astype
         bsr_matrix.check_format
         bsr_matrix.conj
         bsr_matrix.conjugate
         bsr_matrix.copy
         bsr_matrix.diagonal
         bsr_matrix.dot
         bsr_matrix.eliminate_zeros
         bsr_matrix.getH
         bsr_matrix.get_shape
         bsr_matrix.getcol
         bsr_matrix.getdata
         bsr_matrix.getformat
         bsr_matrix.getmaxprint
         bsr_matrix.getnnz
         bsr_matrix.getrow
         bsr_matrix.matmat
         bsr_matrix.matvec
         bsr_matrix.mean
         bsr_matrix.multiply
         bsr_matrix.nonzero
         bsr_matrix.prune
         bsr_matrix.reshape
         bsr_matrix.set_shape
         bsr_matrix.setdiag
         bsr_matrix.sort_indices
         bsr_matrix.sorted_indices
         bsr_matrix.sum
         bsr_matrix.sum_duplicates
         bsr_matrix.toarray
         bsr_matrix.tobsr
         bsr_matrix.tocoo
         bsr_matrix.tocsc
         bsr_matrix.tocsr
         bsr_matrix.todense
         bsr_matrix.todia
         bsr_matrix.todok
         bsr_matrix.tolil
         bsr_matrix.transpose



   

   .. HACK
      .. autosummary::
         :toctree:
      
         bsr_matrix.blocksize
         bsr_matrix.dtype
         bsr_matrix.has_sorted_indices
         bsr_matrix.nnz
         bsr_matrix.shape

